==> php83-nextcloud-28.0.6.tgz: share/nextcloud/apps/activity/l10n/fa.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "feed فعالیت شخصی برای %s",
    "Your feed URL is invalid" : "URL feed شما نامعتبر است",
    "Activity feed for %1$s" : "خوراک فعالیت برای %1$s",
    "Activity feed" : "feed فعالیت",
    "Your settings have been updated." : "تنظیمات شما به روز رسانی شد",
    "Settings have been updated." : "تنظیمات به روز رسانی شد ",
    "Recent activity" : "فعالیت‌های اخیر",
    "No activities" : "بدون فعالیت",
    "More activities" : "فعالیت‌های بیش‌تر",
    "Daily activity summary for %s" : "خلاصهٔ فعّالیت‌های روزانه برای %s",
    "_and %n more _::_and %n more _" : ["و %n بیشتر","و %n بیشتر"],
    "All activities" : "تمامی فعالیت ها",
    "By others" : "توسط دیگران",
    "By you" : "توسط شما",
    "Activity at %s" : "فعّالیت در %s",
    "Hello %s" : "سلام %s",
    "Hello %s," : "سلام %s",
    "There was some activity at %s" : "تعدادی فعالیت در %s وجود دارد",
    "Mail" : "ایمیل",
    "Push" : "فرستادن",
    "Activity" : "فعالیت",
    "Notifications" : "آگاهی‌ها",
    "This application enables people to view a log of activities about them, their files or other data." : "این برنامه می‌گذارد افراد گزارشی از فعّالیت‌های مربوط به خودشان، پرونده‌هایشان یا داده‌ای دیگر را ببینند.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "این کاره می‌گذارد کاربران کنش‌های مربوط به پرونده‌ها و داده‌هایشان را در نکست‌کلود ببینند.\nهرکسی می‌تواند تنظیمات فعّالیت جداگانه‌اش را در تنظمیات شخصیش پیکربندی کرده\nیا برگزیند که کدام فعّالیت باید به تلفن همراه ارسال شده، با رایانامه فرستده شد\nیا این که باید خلاصهٔ روزانه‌ای در هر صبح فرستاده شود یا نه.\nاطّلاعات بیش‌تر در مستندات فعّالیت موجود است.",
    "Activity notification configuration" : "پیکربندی آگاهی‌های فعالیت",
    "Send email" : "فرستادن رایانامه",
    "Send push notification" : "فرستادن آگاهی ارسالی",
    "Today" : "امروز",
    "Yesterday" : "دیروز",
    "You need to set up your email address before you can receive notification emails." : "قبل از دریافت ایمیل های هشدار می بایست ادرس ایمیل خود را تنظیم کنید",
    "Send activity emails" : "فرستادن رایانامه‌های فعالیت",
    "As soon as possible" : "هرچه زودتر",
    "Hourly" : "به طور ساعتی",
    "Daily" : "روزانه",
    "Weekly" : "هفته گی",
    "You commented" : "شما نظر خود را ارسال کردید",
    "Message deleted by author" : "پیام توسط نویسنده حذف شد",
    "Open {filename}" : "گشودن {filename}",
    "in {path}" : "در { مسیر }",
    "Home" : "خانه",
    "Loading activities" : "در حال بارگیری فعالیت‌های",
    "This stream will show events like additions, changes & shares" : "این رسانه به شما رویدادهایی نظیر تغیرات و به اشتراک گذاشته ها را نشان می دهد ",
    "No activity yet" : "هنوز فعالیتی انجام نشده",
    "Loading more activities" : "در حال بارگیری فعالیت‌های بیشتر",
    "No more activities." : "دیگر هیچ فعالیتی وجود ندارد.",
    "Could not load activities" : "فعالیت‌ها بارگیری نشد",
    "Activity settings" : "تنظیمات فعالیت",
    "Enable RSS feed" : "فعالسازی فید RSS",
    "RSS feed" : "خوراک RSS",
    "Copy RSS feed link" : "رونوشت از پیوند خوراک RSS",
    "Personal notification settings" : "تنظیمات آگاهی شخصی",
    "Could not enable RSS link" : "پیوند RSS فعال نشد",
    "RSS link copied to clipboard" : "پیوند RSS در حافظهٔ کلیپ‌بورد کپی شد",
    "Could not copy the RSS link, please copy manually:" : "پیوند RSS کپی نشد، لطفا به صورت دستی کپی کنید:",
    "Unable to load the activity list" : "ناتوان در بارگذاری سیاههٔ فعّالیت",
    "Notification" : "آگاهی",
    "Enable notification emails" : "به کار انداختن رایانامه‌های آگاهی",
    "Choose for which activities you want to get an email or push notification." : "گزینش فعّالیت‌هایی که می‌خواهید برایشان رایانامه یا آگاهی ارسالی بگیرید.",
    "Choose for which activities you want to get a push notification." : "گزینش فعّالیت‌هایی که می‌خواهید برایشان آگاهی ارسالی بگیرید.",
    "Daily activity summary" : "خلاصهٔ فعّالیت‌های روزانه",
    "Send daily activity summary in the morning" : "فرستادن خلاصهٔ فعّالیت‌های روزانه در صبح",
    "Default settings" : "تنظیمات پیش فرض",
    "Configure the default notification settings for new accounts." : "پیکربندی تنظیمات آگاهی پیش‌گزیده برای حساب‌های جدید.",
    "Unable to save the settings" : "ناتوان در ذخیرهٔ تنظیمات",
    "No more events to load" : "رویداد دیگری برای بارگزاری وجود ندارد",
    "Copied!" : "کپی انجام شد!",
    "Not supported!" : "پشتیبانی نشده!",
    "Press ⌘-C to copy." : "برای کپی کردن از دکمه های ویندوز و c  استفاده نمایید ",
    "Press Ctrl-C to copy." : "برای کپی کردن از دکمه ctrl+c استفاده نمایید",
    "{name} (invisible)" : "{نام} (غیر قایل نمایش)",
    "{name} (restricted)" : "{نام } (دسترسی محدود) ",
    "There are no events for this filter" : "هیچ رخدادی برای این فیلتر وجود ندارد",
    "Could not load activites" : "فعالیت بارگیری نشد"
},
"nplurals=2; plural=(n > 1);");

==> php83-nextcloud-30.0.11.tgz: share/nextcloud/apps/activity/l10n/fa.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "feed فعالیت شخصی برای %s",
    "Your feed URL is invalid" : "URL feed شما نامعتبر است",
    "Activity feed for %1$s" : "خوراک فعالیت برای %1$s",
    "Activity feed" : "feed فعالیت",
    "Your settings have been updated." : "تنظیمات شما به روز رسانی شد",
    "Settings have been updated." : "تنظیمات به روز رسانی شد ",
    "Recent activity" : "فعالیت‌های اخیر",
    "No activities" : "بدون فعالیت",
    "More activities" : "فعالیت‌های بیش‌تر",
    "Daily activity summary for %s" : "خلاصهٔ فعّالیت‌های روزانه برای %s",
    "_and %n more…_::_and %n more…_" : ["و یک مورد دیگر...","و %n مورد دیگر..."],
    "All activities" : "تمامی فعالیت ها",
    "By others" : "توسط دیگران",
    "By you" : "توسط شما",
    "Activity at %s" : "فعّالیت در %s",
    "Hello %s" : "سلام %s",
    "Hello %s," : "سلام %s",
    "There was some activity at %s" : "تعدادی فعالیت در %s وجود دارد",
    "_and %n more _::_and %n more _" : ["و %n بیشتر","و %n بیشتر"],
    "Mail" : "ایمیل",
    "Push" : "فرستادن",
    "Activity" : "فعالیت",
    "Notifications" : "آگاهی‌ها",
    "This application enables people to view a log of activities about them, their files or other data." : "این برنامه می‌گذارد افراد گزارشی از فعّالیت‌های مربوط به خودشان، پرونده‌هایشان یا داده‌ای دیگر را ببینند.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "این کاره می‌گذارد کاربران کنش‌های مربوط به پرونده‌ها و داده‌هایشان را در نکست‌کلود ببینند.\n\t\tهرکسی می‌تواند تنظیمات فعّالیت جداگانه‌اش را در تنظمیات شخصیش پیکربندی کرده\n\t\tیا برگزیند که کدام فعّالیت باید به تلفن همراه ارسال شده، با رایانامه فرستده شد\n\t\tیا این که باید خلاصهٔ روزانه‌ای در هر صبح فرستاده شود یا نه.\n\t\tاطّلاعات بیش‌تر در مستندات فعّالیت موجود است.",
    "Send email" : "فرستادن رایانامه",
    "Send push notification" : "فرستادن آگاهی ارسالی",
    "Activity notification configuration" : "پیکربندی آگاهی‌های فعالیت",
    "Today" : "امروز",
    "Yesterday" : "دیروز",
    "You need to set up your email address before you can receive notification emails." : "قبل از دریافت ایمیل های هشدار می بایست ادرس ایمیل خود را تنظیم کنید",
    "Send activity emails" : "فرستادن رایانامه‌های فعالیت",
    "As soon as possible" : "هرچه زودتر",
    "Hourly" : "به طور ساعتی",
    "Daily" : "روزانه",
    "Weekly" : "هفته گی",
    "You commented" : "شما نظر خود را ارسال کردید",
    "Message deleted by author" : "پیام توسط نویسنده حذف شده",
    "Open {filename}" : "گشودن {filename}",
    "in {path}" : "در { مسیر }",
    "Home" : "خانه",
    "Could not load activities" : "فعالیت‌ها بارگیری نشد",
    "Loading activities" : "در حال بارگیری فعالیت‌ها",
    "This stream will show events like additions, changes & shares" : "این رسانه به شما رویدادهایی نظیر تغیرات و به اشتراک گذاشته ها را نشان می دهد ",
    "No activity yet" : "هنوز فعالیتی انجام نشده",
    "Loading more activities" : "بارگیری فعالیت‌های بیشتر",
    "No more activities." : "فعالیت دیگری وجود ندارد.",
    "Could not enable RSS link" : "پیوند RSS فعال نشد",
    "RSS link copied to clipboard" : "پیوند RSS در حافظهٔ کلیپ‌بورد کپی شد",
    "Could not copy the RSS link, please copy manually:" : "پیوند RSS کپی نشد، لطفا به صورت دستی کپی کنید:",
    "Activity settings" : "تنظیمات فعالیت",
    "Enable RSS feed" : "فعالسازی فید RSS",
    "RSS feed" : "خوراک RSS",
    "Copy RSS feed link" : "رونوشت از پیوند خوراک RSS",
    "Personal notification settings" : "تنظیمات آگاهی شخصی",
    "Unable to load the activity list" : "ناتوان در بارگذاری سیاههٔ فعّالیت",
    "Choose for which activities you want to get an email or push notification." : "گزینش فعّالیت‌هایی که می‌خواهید برایشان رایانامه یا آگاهی ارسالی بگیرید.",
    "Choose for which activities you want to get a push notification." : "گزینش فعّالیت‌هایی که می‌خواهید برایشان آگاهی ارسالی بگیرید.",
    "Notification" : "آگاهی",
    "Enable notification emails" : "به کار انداختن رایانامه‌های آگاهی",
    "Daily activity summary" : "خلاصهٔ فعّالیت‌های روزانه",
    "Send daily activity summary in the morning" : "فرستادن خلاصهٔ فعّالیت‌های روزانه در صبح",
    "Default settings" : "تنظیمات پیش فرض",
    "Configure the default notification settings for new accounts." : "پیکربندی تنظیمات آگاهی پیش‌گزیده برای حساب‌های جدید.",
    "Unable to save the settings" : "ناتوان در ذخیرهٔ تنظیمات",
    "No more events to load" : "رویداد دیگری برای بارگزاری وجود ندارد"
},
"nplurals=2; plural=(n > 1);");
